@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2025, University of Cincinnati, developed by Henry Schreiner
+// Copyright (c) 2017-2026, University of Cincinnati, developed by Henry Schreiner
 // under NSF AWARD 1414736 and by the respective contributors.
 // All rights reserved.
 //
@@ -12,7 +12,7 @@
 int main(int argc, char **argv) {
 
     CLI::App app("Prefix command app");
-    app.prefix_command();
+    app.prefix_command(CLI::PrefixCommandMode::On);
 
     std::vector<int> vals;
     app.add_option("--vals,-v", vals)->expected(-1);
