@@ -1,23 +1,36 @@
-// Copyright (c) 2017-2025, University of Cincinnati, developed by Henry Schreiner
+// Copyright (c) 2017-2026, University of Cincinnati, developed by Henry Schreiner
 // under NSF AWARD 1414736 and by the respective contributors.
 // All rights reserved.
 //
 // SPDX-License-Identifier: BSD-3-Clause
 
 #include "app_helper.hpp"
-#include <cmath>
 
 #include <array>
+#include <cmath>
 #include <complex>
 #include <cstdint>
-#include <cstdlib>
 #include <limits>
-#include <map>
 #include <string>
 #include <tuple>
 #include <utility>
 #include <vector>
 
+#ifdef _WIN32
+#define PLATFORM_TEXT(x) _PLATFORM_TEXT(x)
+#define _PLATFORM_TEXT(x) L##x
+using tchar = wchar_t;
+#include <process.h>
+#else
+#define PLATFORM_TEXT(x) x
+using tchar = char;
+#include <csignal>
+#include <cstring>
+#include <spawn.h>
+#include <sys/wait.h>
+#include <unistd.h>
+#endif
+
 TEST_CASE_METHOD(TApp, "OneFlagShort", "[app]") {
     app.add_flag("-c,--count");
     args = {"-c"};
@@ -1025,6 +1038,51 @@ TEST_CASE_METHOD(TApp, "TakeFirstOptMulti", "[app]") {
     CHECK(std::vector<int>({1, 2}) == vals);
 }
 
+TEST_CASE_METHOD(TApp, "optionPriority", "[app]") {
+    std::vector<int> results;
+    auto *opt1 = app.add_flag_callback("-A", [&]() { results.push_back(1); });
+    auto *opt2 = app.add_flag_callback("-B", [&]() { results.push_back(2); });
+    auto *opt3 = app.add_flag_callback("-C", [&]() { results.push_back(3); });
+    auto *opt4 = app.add_flag_callback("-D", [&]() { results.push_back(4); });
+    auto *opt5 = app.add_flag_callback("-E", [&]() { results.push_back(5); });
+    args = {"-A", "-B", "-C", "-D", "-E"};
+    run();
+    CHECK(std::vector<int>({1, 2, 3, 4, 5}) == results);
+    results.clear();
+    opt2->callback_priority(CLI::CallbackPriority::FirstPreHelp);
+    run();
+    CHECK(std::vector<int>({2, 1, 3, 4, 5}) == results);
+    results.clear();
+    opt4->callback_priority(CLI::CallbackPriority::Last);
+    run();
+    CHECK(std::vector<int>({2, 1, 3, 5, 4}) == results);
+    results.clear();
+    opt5->callback_priority(CLI::CallbackPriority::PreRequirementsCheck);
+    run();
+    CHECK(std::vector<int>({2, 5, 1, 3, 4}) == results);
+    results.clear();
+
+    args = {"-A", "-B", "-C", "-D", "-E", "--help"};
+    CHECK_THROWS(run());
+    CHECK(std::vector<int>({2}) == results);
+    results.clear();
+
+    app.get_help_ptr()->callback_priority(CLI::CallbackPriority::Normal);
+    CHECK_THROWS(run());
+    CHECK(std::vector<int>({2, 5}) == results);
+    results.clear();
+
+    app.get_help_ptr()->callback_priority(CLI::CallbackPriority::Last);
+    CHECK_THROWS(run());
+    CHECK(std::vector<int>({2, 5, 1, 3}) == results);
+    results.clear();
+    opt3->excludes(opt1);
+    args = {"-A", "-B", "-C", "-D", "-E"};
+
+    CHECK_THROWS(run());
+    CHECK(std::vector<int>({2, 5}) == results);
+}
+
 TEST_CASE_METHOD(TApp, "ComplexOptMulti", "[app]") {
     std::complex<double> val;
     app.add_option("--long", val)->take_first()->allow_extra_args();
@@ -1259,6 +1317,21 @@ TEST_CASE_METHOD(TApp, "ExpectedRangeParam", "[app]") {
     args = {"-s", "one", "two", "three", "four", "five"};
 
     CHECK_THROWS_AS(run(), CLI::ExtrasError);
+
+    args = {"-s", "one", "two", "three", "four", "five", "six", "seven"};
+
+    try {
+        run();
+        CHECK(false);
+    } catch(const CLI::ExtrasError &err) {
+        std::string message = err.what();
+        auto fiveloc = message.find("five");
+        auto sixloc = message.find("six");
+        auto sevenloc = message.find("seven");
+        CHECK(fiveloc < sixloc);
+        CHECK(sixloc < sevenloc);
+        CHECK(sevenloc != std::string::npos);
+    }
 }
 
 TEST_CASE_METHOD(TApp, "ExpectedRangePositional", "[app]") {
@@ -1325,7 +1398,15 @@ TEST_CASE_METHOD(TApp, "PositionalAtEnd", "[app]") {
     CHECK("param1" == foo);
 
     args = {"param2", "-O", "Test"};
-    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+    try {
+        run();
+        CHECK(false);
+    } catch(const CLI::ExtrasError &err) {
+        std::string message = err.what();
+        auto oloc = message.find("-O");
+        auto tloc = message.find("Test");
+        CHECK(oloc < tloc);
+    }
 }
 
 // Tests positionals at end
@@ -1410,30 +1491,6 @@ TEST_CASE_METHOD(TApp, "RequiredPositionalValidation", "[app]") {
     CHECK("string" == d2);
 }
 
-// Tests positionals at end
-TEST_CASE_METHOD(TApp, "PositionalValidation", "[app]") {
-    std::string options;
-    std::string foo;
-
-    app.add_option("bar", options)->check(CLI::Number.name("valbar"));
-    // disable the check on foo
-    app.add_option("foo", foo)->check(CLI::Number.active(false));
-    app.validate_positionals();
-    args = {"1", "param1"};
-    run();
-
-    CHECK("1" == options);
-    CHECK("param1" == foo);
-
-    args = {"param1", "1"};
-    CHECK_NOTHROW(run());
-
-    CHECK("1" == options);
-    CHECK("param1" == foo);
-
-    CHECK(nullptr != app.get_option("bar")->get_validator("valbar"));
-}
-
 TEST_CASE_METHOD(TApp, "PositionalNoSpaceLong", "[app]") {
     std::vector<std::string> options;
     std::string foo, bar;
@@ -1806,6 +1863,8 @@ TEST_CASE_METHOD(TApp, "BigPositional", "[app]") {
     CHECK(vec == args);
 }
 
+#if (defined(CLI11_ENABLE_EXTRA_VALIDATORS) && CLI11_ENABLE_EXTRA_VALIDATORS == 1) ||                                  \
+    (!defined(CLI11_DISABLE_EXTRA_VALIDATORS) || CLI11_DISABLE_EXTRA_VALIDATORS == 0)
 TEST_CASE_METHOD(TApp, "VectorArgAndPositional", "[app]") {
     std::vector<std::string> vec;
     std::vector<int> ivec;
@@ -1833,6 +1892,7 @@ TEST_CASE_METHOD(TApp, "VectorArgAndPositional", "[app]") {
     app.validate_optional_arguments(false);
     CHECK_THROWS(run());
 }
+#endif
 
 TEST_CASE_METHOD(TApp, "Reset", "[app]") {
 
@@ -1921,25 +1981,6 @@ TEST_CASE_METHOD(TApp, "FileNotExists", "[app]") {
     CHECK(!CLI::ExistingFile(myfile).empty());
 }
 
-TEST_CASE_METHOD(TApp, "FileExists", "[app]") {
-    std::string myfile{"TestNonFileNotUsed.txt"};
-    CHECK(!CLI::ExistingFile(myfile).empty());
-
-    std::string filename = "Failed";
-    app.add_option("--file", filename)->check(CLI::ExistingFile);
-    args = {"--file", myfile};
-
-    CHECK_THROWS_AS(run(), CLI::ValidationError);
-
-    bool ok = static_cast<bool>(std::ofstream(myfile.c_str()).put('a'));  // create file
-    CHECK(ok);
-    run();
-    CHECK(filename == myfile);
-
-    std::remove(myfile.c_str());
-    CHECK(!CLI::ExistingFile(myfile).empty());
-}
-
 #if defined CLI11_HAS_FILESYSTEM && CLI11_HAS_FILESYSTEM > 0 && defined(_MSC_VER)
 TEST_CASE_METHOD(TApp, "filesystemWideName", "[app]") {
     std::filesystem::path myfile{L"voil\u20ac.txt"};
@@ -1982,6 +2023,25 @@ TEST_CASE_METHOD(TApp, "NotFileExists", "[app]") {
     CHECK(!CLI::ExistingFile(myfile).empty());
 }
 
+TEST_CASE_METHOD(TApp, "FileExists", "[app]") {
+    std::string myfile{"TestNonFileNotUsed.txt"};
+    CHECK(!CLI::ExistingFile(myfile).empty());
+
+    std::string filename = "Failed";
+    app.add_option("--file", filename)->check(CLI::ExistingFile);
+    args = {"--file", myfile};
+
+    CHECK_THROWS_AS(run(), CLI::ValidationError);
+
+    bool ok = static_cast<bool>(std::ofstream(myfile.c_str()).put('a'));  // create file
+    CHECK(ok);
+    run();
+    CHECK(filename == myfile);
+
+    std::remove(myfile.c_str());
+    CHECK(!CLI::ExistingFile(myfile).empty());
+}
+
 TEST_CASE_METHOD(TApp, "DefaultedResult", "[app]") {
     std::string sval = "NA";
     int ival{0};
@@ -2014,6 +2074,8 @@ TEST_CASE_METHOD(TApp, "OriginalOrder", "[app]") {
     CHECK(std::vector<int>({2}) == st2);
 
     CHECK(std::vector<CLI::Option *>({op1, op2, op1, op1}) == app.parse_order());
+    app.clear();
+    CHECK(app.parse_order().empty());
 }
 
 TEST_CASE_METHOD(TApp, "NeedsFlags", "[app]") {
@@ -2034,6 +2096,19 @@ TEST_CASE_METHOD(TApp, "NeedsFlags", "[app]") {
     CHECK_NOTHROW(opt->needs(opt));
 }
 
+TEST_CASE_METHOD(TApp, "needsOptionFunction", "[app]") {
+    std::string s1{"A"};
+    std::string s2{"B"};
+    app.add_flag("-s,--string");
+    app.add_option_function<std::string>("file", [&](std::string const &str) { s1 = str; }, "input file");
+    app.add_option_function<std::string>(
+           "--something", [&](std::string const &str) { s2 = str; }, "something")
+        ->needs("file");
+    args = {"--something", "C"};
+    CHECK_THROWS_AS(run(), CLI::RequiresError);
+    CHECK(s2 == "B");
+}
+
 TEST_CASE_METHOD(TApp, "ExcludesFlags", "[app]") {
     CLI::Option *opt = app.add_flag("-s,--string");
     app.add_flag("--nostr")->excludes(opt);
@@ -2291,24 +2366,6 @@ TEST_CASE_METHOD(TApp, "NonNegative", "[app]") {
     }
 }
 
-TEST_CASE_METHOD(TApp, "typeCheck", "[app]") {
-
-    /// Note that this must be a double in Range, too
-    app.add_option("--one")->check(CLI::TypeValidator<unsigned int>());
-
-    args = {"--one=1"};
-    CHECK_NOTHROW(run());
-
-    args = {"--one=-7"};
-    CHECK_THROWS_AS(run(), CLI::ValidationError);
-
-    args = {"--one=error"};
-    CHECK_THROWS_AS(run(), CLI::ValidationError);
-
-    args = {"--one=4.568"};
-    CHECK_THROWS_AS(run(), CLI::ValidationError);
-}
-
 TEST_CASE_METHOD(TApp, "NeedsTrue", "[app]") {
     std::string str;
     app.add_option("-s,--string", str);
@@ -2347,6 +2404,12 @@ TEST_CASE_METHOD(TApp, "AllowExtras", "[app]") {
     REQUIRE_NOTHROW(run());
     CHECK(val);
     CHECK(std::vector<std::string>({"-x"}) == app.remaining());
+
+    app.allow_extras(CLI::ExtrasMode::Ignore);
+    val = false;
+    REQUIRE_NOTHROW(run());
+    CHECK(val);
+    CHECK(app.remaining().empty());
 }
 
 TEST_CASE_METHOD(TApp, "AllowExtrasOrder", "[app]") {
@@ -2366,7 +2429,6 @@ TEST_CASE_METHOD(TApp, "AllowExtrasOrder", "[app]") {
 TEST_CASE_METHOD(TApp, "AllowExtrasCascade", "[app]") {
 
     app.allow_extras();
-
     args = {"-x", "45", "-f", "27"};
     REQUIRE_NOTHROW(run());
     CHECK(std::vector<std::string>({"-x", "45", "-f", "27"}) == app.remaining());
@@ -2383,10 +2445,124 @@ TEST_CASE_METHOD(TApp, "AllowExtrasCascade", "[app]") {
     CHECK(45 == v1);
     CHECK(27 == v2);
 }
+
+TEST_CASE_METHOD(TApp, "AllowExtrasAssumptions", "[app]") {
+
+    app.allow_extras(CLI::ExtrasMode::AssumeSingleArgument);
+
+    std::string one;
+    std::string two;
+    app.add_option("--one", one);
+    app.add_option("two", two);
+    args = {"--one", "45", "--three", "27", "this"};
+
+    REQUIRE_NOTHROW(run());
+    CHECK(one == "45");
+    CHECK(two == "this");
+    CHECK(app.remaining().size() == 2U);
+
+    two.clear();
+    app.allow_extras(CLI::ExtrasMode::AssumeMultipleArguments);
+
+    run();
+    CHECK(one == "45");
+    CHECK(two.empty());
+    CHECK(app.remaining().size() == 3U);
+    app.allow_extras(CLI::ExtrasMode::AssumeSingleArgument);
+    CHECK(app.get_allow_extras_mode() == CLI::ExtrasMode::AssumeSingleArgument);
+    args = {"--three", "27", "--one", "45", "this"};
+    run();
+    CHECK(one == "45");
+    CHECK(two == "this");
+    CHECK(app.remaining().size() == 2U);
+
+    app.allow_extras(CLI::ExtrasMode::AssumeMultipleArguments);
+    CHECK(app.get_allow_extras_mode() == CLI::ExtrasMode::AssumeMultipleArguments);
+    args = {"--three", "27", "extra", "--one", "45", "this"};
+    one.clear();
+    two.clear();
+    run();
+    CHECK(one == "45");
+    CHECK(two == "this");
+    CHECK(app.remaining().size() == 3U);
+}
+
+TEST_CASE_METHOD(TApp, "AllowExtrasImmediateError", "[app]") {
+
+    int v1{0};
+    int v2{0};
+    app.add_option("-f", v1)->trigger_on_parse();
+    app.add_option("-x", v2);
+    args = {"-x", "15", "-f", "17", "-g", "19"};
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+    CHECK(v1 == 17);
+    CHECK(app.remaining().size() == 2U);
+    args = {"-x", "21", "-f", "23", "-g", "25"};
+    app.allow_extras(CLI::ExtrasMode::ErrorImmediately);
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+    CHECK(v1 == 23);  // -f still triggers
+    CHECK(v2 == 15);
+    CHECK(app.remaining().empty());
+    args = {"-x", "27", "-g", "29", "-f", "31"};
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+    CHECK(v1 == 23);  // -f did not trigger
+    CHECK(v2 == 15);
+    CHECK(app.remaining().empty());
+}
+
+TEST_CASE_METHOD(TApp, "PrefixCommand", "[app]") {
+    int v1{0};
+    int v2{0};
+    app.add_option("-f", v1);
+    app.add_option("-x", v2);
+    app.prefix_command();
+    args = {"-x", "45", "-f", "27"};
+    run();
+    auto rem = app.remaining();
+    CHECK(rem.empty());
+
+    args = {"-x", "45", "-f", "27", "--test", "23"};
+
+    run();
+    rem = app.remaining();
+    CHECK(rem.size() == 2U);
+
+    args = {"-x", "45", "-f", "27", "--", "--test", "23"};
+
+    run();
+    rem = app.remaining();
+    CHECK(rem.size() == 3U);
+
+    args = {"-x", "45", "--test4", "-f", "27", "--test", "23"};
+
+    run();
+    rem = app.remaining();
+    CHECK(rem.size() == 5U);
+
+    app.prefix_command(CLI::PrefixCommandMode::SeparatorOnly);
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+
+    args = {"-x", "45", "positional", "-f", "27", "--test", "23"};
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+
+    args = {"-x", "45", "-f", "27", "--", "--test", "23"};
+
+    run();
+    rem = app.remaining();
+    CHECK(rem.size() == 3U);
+
+    args = {"-x", "45", "--test4", "-f", "27", "--", "--test", "23"};
+
+    CHECK_THROWS_AS(run(), CLI::ExtrasError);
+    app.allow_extras(true);
+    run();
+    rem = app.remaining();
+    CHECK(rem.size() == 4U);
+}
+
 // makes sure the error throws on the rValue version of the parse
 TEST_CASE_METHOD(TApp, "ExtrasErrorRvalueParse", "[app]") {
 
-    args = {"-x", "45", "-f", "27"};
     CHECK_THROWS_AS(app.parse(std::vector<std::string>({"-x", "45", "-f", "27"})), CLI::ExtrasError);
 }
 
@@ -2467,10 +2643,6 @@ TEST_CASE_METHOD(TApp, "CheckSubcomFail", "[app]") {
     CHECK_THROWS_AS(CLI::detail::AppFriend::parse_subcommand(&app, args), CLI::HorribleError);
 }
 
-TEST_CASE_METHOD(TApp, "FallthroughParentFail", "[app]") {
-    CHECK_THROWS_AS(CLI::detail::AppFriend::get_fallthrough_parent(&app), CLI::HorribleError);
-}
-
 TEST_CASE_METHOD(TApp, "FallthroughParents", "[app]") {
     auto *sub = app.add_subcommand("test");
     CHECK(&app == CLI::detail::AppFriend::get_fallthrough_parent(sub));
@@ -2490,6 +2662,31 @@ TEST_CASE_METHOD(TApp, "FallthroughParents", "[app]") {
 
     ogb2->name("groupb");
     CHECK(ogb2 == CLI::detail::AppFriend::get_fallthrough_parent(ogb3));
+
+    CHECK(CLI::detail::AppFriend::get_fallthrough_parent(&app) == nullptr);
+}
+
+TEST_CASE_METHOD(TApp, "ConstFallthroughParents", "[app]") {
+    auto *sub = app.add_subcommand("test");
+    CHECK(&app == CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::App *>(sub)));
+
+    auto *ssub = sub->add_subcommand("sub2");
+    CHECK(sub == CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::App *>(ssub)));
+
+    auto *og1 = app.add_option_group("g1");
+    auto *og2 = og1->add_option_group("g2");
+    auto *og3 = og2->add_option_group("g3");
+    CHECK(&app == CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::Option_group *>(og3)));
+
+    auto *ogb1 = sub->add_option_group("g1");
+    auto *ogb2 = ogb1->add_option_group("g2");
+    auto *ogb3 = ogb2->add_option_group("g3");
+    CHECK(sub == CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::Option_group *>(ogb3)));
+
+    ogb2->name("groupb");
+    CHECK(ogb2 == CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::Option_group *>(ogb3)));
+
+    CHECK(CLI::detail::AppFriend::get_fallthrough_parent(const_cast<const CLI::App *>(&app)) == nullptr);
 }
 
 TEST_CASE_METHOD(TApp, "OptionWithDefaults", "[app]") {
@@ -2615,7 +2812,6 @@ TEST_CASE_METHOD(TApp, "EmptyOptionEach", "[app]") {
 
 // #122
 TEST_CASE_METHOD(TApp, "EmptyOptionFail", "[app]") {
-    std::string q;
     app.add_option("--each");
 
     args = {"--each", "that"};
@@ -2683,7 +2879,7 @@ TEST_CASE_METHOD(TApp, "BadUserSepParse", "[app]") {
     std::vector<int> vals;
     app.add_option("--idx", vals);
 
-    args = {"--idx", "1,2,3"};
+    args = {"--idx", "1;2;3"};
 
     CHECK_THROWS_AS(run(), CLI::ConversionError);
 }
@@ -2817,38 +3013,108 @@ TEST_CASE("C20_compile", "simple") {
     CHECK_FALSE(flag->empty());
 }
 
+#ifdef _WIN32
+static int spawn_subprocess_win32(const wchar_t *path, wchar_t *commandline) {
+    STARTUPINFOW si{};
+    si.cb = sizeof(si);
+    PROCESS_INFORMATION pi{};
+    REQUIRE(CreateProcessW(path, commandline, nullptr, nullptr, FALSE, 0, nullptr, nullptr, &si, &pi));
+    WaitForSingleObject(pi.hProcess, INFINITE);
+
+    DWORD exitcode;  // NOLINT(cppcoreguidelines-init-variables)
+    REQUIRE(GetExitCodeProcess(pi.hProcess, &exitcode));
+
+    return static_cast<int>(exitcode);
+}
+#else
+#include <pthread.h>
+static int spawn_subprocess_posix(const char *path, char *const *argv) {
+    // NOLINTBEGIN(cppcoreguidelines-init-variables)
+    pid_t pid;
+    sigset_t old, reset;
+    struct sigaction sa, oldint, oldquit;
+    std::memset(&sa, 0, sizeof(sa));
+    sa.sa_handler = SIG_IGN;
+    int status = -1, ret;
+    posix_spawnattr_t attr;
+    // NOLINTEND(cppcoreguidelines-init-variables)
+
+    pthread_testcancel();
+
+    sigaction(SIGINT, &sa, &oldint);
+    sigaction(SIGQUIT, &sa, &oldquit);
+    sigaddset(&sa.sa_mask, SIGCHLD);
+    sigprocmask(SIG_BLOCK, &sa.sa_mask, &old);
+
+    sigemptyset(&reset);
+    if(oldint.sa_handler != SIG_IGN)
+        sigaddset(&reset, SIGINT);
+    if(oldquit.sa_handler != SIG_IGN)
+        sigaddset(&reset, SIGQUIT);
+    posix_spawnattr_init(&attr);
+    posix_spawnattr_setsigmask(&attr, &old);
+    posix_spawnattr_setsigdefault(&attr, &reset);
+    posix_spawnattr_setflags(&attr, POSIX_SPAWN_SETSIGDEF | POSIX_SPAWN_SETSIGMASK);
+    CHECK((ret = posix_spawn(&pid, path, nullptr, &attr, argv, nullptr)) == 0);
+
+    if(ret == 0)
+        while(waitpid(pid, &status, 0) < 0 && errno != EINTR) {
+        }
+
+    sigaction(SIGINT, &oldint, nullptr);
+    sigaction(SIGQUIT, &oldquit, nullptr);
+    sigprocmask(SIG_SETMASK, &old, nullptr);
+
+    return status;
+}
+#endif
+
+static int spawn_app_exe(const tchar *path) {
+#ifdef _WIN32
+    std::wstring args{L"app_exe 1234 false \"hello world\""};
+    return spawn_subprocess_win32(path, &args[0]);
+#else
+    std::string arg0{"app_exe"};
+    std::string arg1{"1234"};
+    std::string arg2{"false"};
+    std::string arg3{"hello world"};
+    // NOLINTNEXTLINE(modernize-avoid-c-arrays)
+    char *const args[] = {&arg0[0], &arg1[0], &arg2[0], &arg3[0], nullptr};
+    return spawn_subprocess_posix(path, args);
+#endif
+}
+
 // #845
 TEST_CASE("Ensure UTF-8", "[app]") {
-    const char *commandline = CLI11_ENSURE_UTF8_EXE " 1234 false \"hello world\"";
-    int retval = std::system(commandline);
+    auto retval = spawn_app_exe(PLATFORM_TEXT(CLI11_ENSURE_UTF8_EXE));
 
     if(retval == -1) {
-        FAIL("Executable '" << commandline << "' reported that argv pointer changed where it should not have been");
+        FAIL("Executable " CLI11_ENSURE_UTF8_EXE " reported that argv pointer changed where it should not have been");
     }
 
     if(retval > 0) {
-        FAIL("Executable '" << commandline << "' reported different argv at index " << (retval - 1));
+        FAIL("Executable " CLI11_ENSURE_UTF8_EXE " reported different argv at index " << (retval - 1));
     }
 
     if(retval != 0) {
-        FAIL("Executable '" << commandline << "' failed with an unknown return code");
+        FAIL("Executable " CLI11_ENSURE_UTF8_EXE " failed with an unknown return code");
     }
 }
 
 // #845
 TEST_CASE("Ensure UTF-8 called twice", "[app]") {
-    const char *commandline = CLI11_ENSURE_UTF8_TWICE_EXE " 1234 false \"hello world\"";
-    int retval = std::system(commandline);
+    auto retval = spawn_app_exe(PLATFORM_TEXT(CLI11_ENSURE_UTF8_TWICE_EXE));
 
     if(retval == -1) {
-        FAIL("Executable '" << commandline << "' reported that argv pointer changed where it should not have been");
+        FAIL("Executable " CLI11_ENSURE_UTF8_TWICE_EXE
+             " reported that argv pointer changed where it should not have been");
     }
 
     if(retval > 0) {
-        FAIL("Executable '" << commandline << "' reported different argv at index " << (retval - 1));
+        FAIL("Executable " CLI11_ENSURE_UTF8_TWICE_EXE " reported different argv at index " << (retval - 1));
     }
 
     if(retval != 0) {
-        FAIL("Executable '" << commandline << "' failed with an unknown return code");
+        FAIL("Executable " CLI11_ENSURE_UTF8_TWICE_EXE " failed with an unknown return code");
     }
 }
